@@ -26,7 +26,7 @@
 
 void print_node(const xmlpp::Node* node, unsigned int indentation = 0)
 {
-  const Glib::ustring indent(indentation, ' ');
+  const std::string indent(indentation, ' ');
 
   const auto nodeContent = dynamic_cast<const xmlpp::ContentNode*>(node);
   const auto nodeText = dynamic_cast<const xmlpp::TextNode*>(node);
@@ -108,15 +108,12 @@ void print_node(const xmlpp::Node* node, unsigned int indentation = 0)
 
 int main(int argc, char* argv[])
 {
-  // Set the global C++ locale to the user-configured locale,
-  // so we can use std::cout with UTF-8, via Glib::ustring, without exceptions.
-  std::locale::global(std::locale(""));
-
   bool validate = false;
   bool set_throw_messages = false;
   bool throw_messages = false;
   bool substitute_entities = true;
   bool generate_xinclude_nodes = true;
+  bool fixup_base_uris = true;
 
   int argi = 1;
   while (argc > argi && *argv[argi] == '-') // option
@@ -140,13 +137,17 @@ int main(int argc, char* argv[])
       case 'X':
         generate_xinclude_nodes = false;
         break;
+      case 'B':
+        fixup_base_uris = false;
+        break;
      default:
-       std::cout << "Usage: " << argv[0] << " [-v] [-t] [-e] [-x] [filename]" << std::endl
+       std::cout << "Usage: " << argv[0] << " [options]... [filename]" << std::endl
                  << "       -v  Validate" << std::endl
                  << "       -t  Throw messages in an exception" << std::endl
                  << "       -e  Write messages to stderr" << std::endl
                  << "       -E  Do not substitute entities" << std::endl
-                 << "       -X  Do not generate XInclude nodes" << std::endl;
+                 << "       -X  Do not generate XInclude nodes" << std::endl
+                 << "       -B  Do not fix up base URIs" << std::endl;
        return EXIT_FAILURE;
      }
      argi++;
@@ -160,8 +161,7 @@ int main(int argc, char* argv[])
   try
   {
     xmlpp::DomParser parser;
-    if (validate)
-      parser.set_validate();
+    parser.set_validate(validate);
     if (set_throw_messages)
       parser.set_throw_messages(throw_messages);
     //We can have the text resolved/unescaped automatically.
@@ -174,14 +174,31 @@ int main(int argc, char* argv[])
       print_node(pNode);
 
       std::cout << std::endl << ">>>>> Number of XInclude substitutions: "
-                << parser.get_document()->process_xinclude(generate_xinclude_nodes)
+                << parser.get_document()->process_xinclude(
+                     generate_xinclude_nodes, fixup_base_uris)
+                << std::endl << std::endl;
+
+      std::cout << ">>>>> After XInclude processing with xmlpp::Document::process_xinclude(): "
                 << std::endl << std::endl;
       pNode = parser.get_document()->get_root_node();
       print_node(pNode);
 
+      // xmlpp::Document::write_to_string() does not write XIncludeStart and
+      // XIncludeEnd nodes.
       const auto whole = parser.get_document()->write_to_string();
-      std::cout << std::endl << ">>>>> XML after XInclude processing: " << std::endl
-                << whole << std::endl;
+      std::cout << std::endl << whole << std::endl;
+    }
+
+    parser.set_xinclude_options(true, generate_xinclude_nodes, fixup_base_uris);
+    parser.parse_file(filepath);
+    if (parser)
+    {
+      std::cout << ">>>>> After XInclude processing with xmlpp::DomParser::parse_file(): "
+                << std::endl << std::endl;
+      print_node(parser.get_document()->get_root_node());
+
+      const auto whole = parser.get_document()->write_to_string();
+      std::cout << std::endl << whole << std::endl;
     }
   }
   catch (const std::exception& ex)
